@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 '''
     This program is free software; you can redistribute it and/or modify
     it under the terms of the Revised BSD License.
@@ -11,7 +12,7 @@
     Copyright 2011-2023 Game Maker 2k - http://intdb.sourceforge.net/
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: precairo.py - Last Update: 2/18/2023/18/2023 Ver. 2.7.20 RC 1  - Author: cooldude2k $
+    $FileInfo: precairo.py - Last Update: 2/19/2023 Ver. 2.7.22 RC 1  - Author: cooldude2k $
 '''
 
 import cairo;
