@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 '''
     This program is free software; you can redistribute it and/or modify
     it under the terms of the Revised BSD License.
@@ -10,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: oopfuncs.py - Last Update: 2/18/2023/18/2023 Ver. 2.7.20 RC 1 - Author: cooldude2k $
+    $FileInfo: oopfuncs.py - Last Update: 2/19/2023 Ver. 2.7.22 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -27,6 +28,7 @@ class barcode:
  EAN5="ean5";
  UPCS5="ean5";
  UPCA="upca";
+ GOODWILL="goodwill";
  UPCE="upce";
  EAN13="ean13"
  EAN8="ean8"
@@ -36,6 +38,7 @@ class barcode:
  CODE11="code11";
  CODE39="code39";
  CODE93="code93";
+ CODE128="code128"
  CODABAR="codabar";
  MSI="msi";
  bctype_dict=upcean.support.bctype_dict;
